account_info_schema = {
    "type":"object",
    "properties":{
        "organization_name":{
            "type":["string","null"],
            "antiSamyLevel":1,
            "maxLength":80,
            "description":"Organization name associated with the account.",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "website": {
            "type":["string","null"],
            "antiSamyLevel":1,
            "pattern":"^$|([Hh][Tt]{2}[Pp][Ss]*):\/\/[\\w\\-_]+(\\.[\\w\\-_]+)+.*?",
            "maxLength":255,
            "description":"The URL of the Web site associated with the account",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "time_zone":{
            "type":["string","null"],
            "antiSamyLevel":1,
            "description":"the time zone associated with the account",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "first_name":{
            "type":["string","null"],
            "antiSamyLevel":1,
            "maxLength":80,
            "description":"the account owner's first name",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "last_name":{
            "type":["string","null"],
            "antiSamyLevel":1,
            "maxLength":80,
            "description":"Last name of the account owner",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "email":{
            "type":["string","null"],
            "format":"email",
            "antiSamyLevel":1,
            "maxLength":80,
            "minLength":6,
            "description":"Email address associated with the account",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "phone":{
            "type":["string","null"],
            "maxLength":20,
            "antiSamyLevel":1,
            "description":"Phone number associated with the account",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "company_logo":{
            "type":["string","null"],
            "antiSamyLevel":1,
            "pattern":"^$|([Hh][Tt]{2}[Pp][Ss]*):\/\/[\\w\\-_]+(\\.[\\w\\-_]+)+.*?",
            "maxLength":255,
            "description":"The URL for the company logo",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "state_code":{
            "type":["string", "null"],
            "antiSamyLevel":1,
            "description":"If in the United States, 2 letter (capitalized) code of the state that the organization sending the email campaign is located, field is case sensitive",
            "displayInPOST":False,
            "displayInPUT":True,
            "displayInGET":True
        },
        "country_code": {
            "type": ["string","null"],
            "enum": [
                "",
                "AF",
                "AX",
                "AL",
                "DZ",
                "AS",
                "AD",
                "AO",
                "AI",
                "AQ",
                "AG",
                "AR",
                "AM",
                "AW",
                "AU",
                "AT",
                "AZ",
                "BS",
                "BH",
                "BD",
                "BB",
                "BY",
                "BE",
                "BZ",
                "BJ",
                "BM",
                "BT",
                "BO",
                "BA",
                "BW",
                "BV",
                "BR",
                "IO",
                "BN",
                "BG",
                "BF",
                "BI",
                "KH",
                "CM",
                "CA",
                "CV",
                "KY",
                "CF",
                "TD",
                "CL",
                "CN",
                "CX",
                "CC",
                "CO",
                "KM",
                "CG",
                "CD",
                "CK",
                "CR",
                "CI",
                "HR",
                "CY",
                "CZ",
                "DK",
                "DJ",
                "DM",
                "DO",
                "TL",
                "EC",
                "EG",
                "SV",
                "U1",
                "GQ",
                "ER",
                "EE",
                "ET",
                "FO",
                "FK",
                "FJ",
                "FI",
                "FR",
                "GF",
                "PF",
                "TF",
                "GA",
                "GM",
                "GE",
                "DE",
                "GH",
                "GI",
                "GR",
                "GL",
                "GD",
                "GP",
                "GU",
                "GT",
                "GG",
                "GN",
                "GW",
                "GY",
                "HT",
                "HM",
                "HN",
                "HK",
                "HU",
                "IS",
                "IN",
                "ID",
                "IQ",
                "IE",
                "IM",
                "IL",
                "IT",
                "JM",
                "JP",
                "JE",
                "JO",
                "KZ",
                "KE",
                "KI",
                "KW",
                "KG",
                "LA",
                "LV",
                "LB",
                "LS",
                "LR",
                "LY",
                "LI",
                "LT",
                "LU",
                "MO",
                "MK",
                "MG",
                "MW",
                "MY",
                "MV",
                "ML",
                "MT",
                "MH",
                "MQ",
                "MR",
                "MU",
                "YT",
                "MX",
                "FM",
                "MD",
                "MC",
                "MN",
                "ME",
                "MS",
                "MA",
                "MZ",
                "MM",
                "NA",
                "NR",
                "NP",
                "NL",
                "AN",
                "NT",
                "NC",
                "NZ",
                "NI",
                "NE",
                "NG",
                "NU",
                "NF",
                "U4",
                "MP",
                "NO",
                "OM",
                "PK",
                "PW",
                "PS",
                "PA",
                "PG",
                "PY",
                "PE",
                "PH",
                "PN",
                "PL",
                "PT",
                "PR",
                "QA",
                "RE",
                "RO",
                "RU",
                "RW",
                "BL",
                "SH",
                "KN",
                "LC",
                "MF",
                "PM",
                "VC",
                "WS",
                "SM",
                "ST",
                "SA",
                "U3",
                "SN",
                "RS",
                "SC",
                "SL",
                "SG",
                "SK",
                "SI",
                "SB",
                "SO",
                "ZA",
                "GS",
                "KR",
                "ES",
                "LK",
                "SR",
                "SJ",
                "SZ",
                "SE",
                "CH",
                "TW",
                "TJ",
                "TZ",
                "TH",
                "TG",
                "TK",
                "TO",
                "TT",
                "TN",
                "TR",
                "TM",
                "TC",
                "TV",
                "UG",
                "UA",
                "AE",
                "GB",
                "US",
                "UM",
                "UY",
                "UZ",
                "VU",
                "VA",
                "VE",
                "VN",
                "VG",
                "VI",
                "U2",
                "WF",
                "EH",
                "YE",
                "ZM",
                "ZW"
            ],
            "maxLength": 2,
            "description": "2 letter ISO 3166-1 code of the country associated with the account",
            "displayInPOST": False,
            "displayInPUT": True,
            "displayInGET": True
        },
        "organization_addresses":{
            "type":["array","null"],
            "description":"Organization's physical address information.",
            "readonly":False,
            "displayInPOST":True,
            "displayInPUT":True,
            "displayInGET":True,
            "maxItems":1,
            "items":{
                "type":["object"],
                "properties":{
                    "line1":{
                        "type":"string",
                        "required":True,
                        "antiSamyLevel":2,
                        "minLength":1,
                        "maxLength":80,
                        "description":"Street Address line 1",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    },
                    "line2":{
                        "type":["string", "null"],
                        "antiSamyLevel":2,
                        "maxLength":80,
                        "description":"Street Address line 2",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    },
                    "line3":{
                        "type":["string", "null"],
                        "antiSamyLevel":2,
                        "maxLength":80,
                        "description":"Street Address line 3",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    },
                    "city":{
                        "type":"string",
                        "required":True,
                        "antiSamyLevel":2,
                        "minLength":1,
                        "maxLength":80,
                        "description":"Organization's city",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    },
                    "postal_code":{
                        "type":["string", "null"],
                        "antiSamyLevel":2,
                        "maxLength":30,
                        "description":"Postal ZIP code for the organization",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    },
                    "country_code":{
                        "type":["string", "null"],
                        "antiSamyLevel":2,
                        "maxLength":2,
                        "required": True,
                        "enum": [
                            "AF",
                            "AX",
                            "AL",
                            "DZ",
                            "AS",
                            "AD",
                            "AO",
                            "AI",
                            "AQ",
                            "AG",
                            "AR",
                            "AM",
                            "AW",
                            "AU",
                            "AT",
                            "AZ",
                            "BS",
                            "BH",
                            "BD",
                            "BB",
                            "BY",
                            "BE",
                            "BZ",
                            "BJ",
                            "BM",
                            "BT",
                            "BO",
                            "BA",
                            "BW",
                            "BV",
                            "BR",
                            "IO",
                            "BN",
                            "BG",
                            "BF",
                            "BI",
                            "KH",
                            "CM",
                            "CA",
                            "CV",
                            "KY",
                            "CF",
                            "TD",
                            "CL",
                            "CN",
                            "CX",
                            "CC",
                            "CO",
                            "KM",
                            "CG",
                            "CD",
                            "CK",
                            "CR",
                            "CI",
                            "HR",
                            "CY",
                            "CZ",
                            "DK",
                            "DJ",
                            "DM",
                            "DO",
                            "TL",
                            "EC",
                            "EG",
                            "SV",
                            "U1",
                            "GQ",
                            "ER",
                            "EE",
                            "ET",
                            "FO",
                            "FK",
                            "FJ",
                            "FI",
                            "FR",
                            "GF",
                            "PF",
                            "TF",
                            "GA",
                            "GM",
                            "GE",
                            "DE",
                            "GH",
                            "GI",
                            "GR",
                            "GL",
                            "GD",
                            "GP",
                            "GU",
                            "GT",
                            "GG",
                            "GN",
                            "GW",
                            "GY",
                            "HT",
                            "HM",
                            "HN",
                            "HK",
                            "HU",
                            "IS",
                            "IN",
                            "ID",
                            "IQ",
                            "IE",
                            "IM",
                            "IL",
                            "IT",
                            "JM",
                            "JP",
                            "JE",
                            "JO",
                            "KZ",
                            "KE",
                            "KI",
                            "KW",
                            "KG",
                            "LA",
                            "LV",
                            "LB",
                            "LS",
                            "LR",
                            "LY",
                            "LI",
                            "LT",
                            "LU",
                            "MO",
                            "MK",
                            "MG",
                            "MW",
                            "MY",
                            "MV",
                            "ML",
                            "MT",
                            "MH",
                            "MQ",
                            "MR",
                            "MU",
                            "YT",
                            "MX",
                            "FM",
                            "MD",
                            "MC",
                            "MN",
                            "ME",
                            "MS",
                            "MA",
                            "MZ",
                            "MM",
                            "NA",
                            "NR",
                            "NP",
                            "NL",
                            "AN",
                            "NT",
                            "NC",
                            "NZ",
                            "NI",
                            "NE",
                            "NG",
                            "NU",
                            "NF",
                            "U4",
                            "MP",
                            "NO",
                            "OM",
                            "PK",
                            "PW",
                            "PS",
                            "PA",
                            "PG",
                            "PY",
                            "PE",
                            "PH",
                            "PN",
                            "PL",
                            "PT",
                            "PR",
                            "QA",
                            "RE",
                            "RO",
                            "RU",
                            "RW",
                            "BL",
                            "SH",
                            "KN",
                            "LC",
                            "MF",
                            "PM",
                            "VC",
                            "WS",
                            "SM",
                            "ST",
                            "SA",
                            "U3",
                            "SN",
                            "RS",
                            "SC",
                            "SL",
                            "SG",
                            "SK",
                            "SI",
                            "SB",
                            "SO",
                            "ZA",
                            "GS",
                            "KR",
                            "ES",
                            "LK",
                            "SR",
                            "SJ",
                            "SZ",
                            "SE",
                            "CH",
                            "TW",
                            "TJ",
                            "TZ",
                            "TH",
                            "TG",
                            "TK",
                            "TO",
                            "TT",
                            "TN",
                            "TR",
                            "TM",
                            "TC",
                            "TV",
                            "UG",
                            "UA",
                            "AE",
                            "GB",
                            "US",
                            "UM",
                            "UY",
                            "UZ",
                            "VU",
                            "VA",
                            "VE",
                            "VN",
                            "VG",
                            "VI",
                            "U2",
                            "WF",
                            "EH",
                            "YE",
                            "ZM",
                            "ZW"
                        ],
                        "description":"Country code for the organization",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    },
                    "state_code":{
                        "type":["string", "null"],
                        "antiSamyLevel":2,
                        "maxLength":2,
                        "description":"State code for the organization",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    },
                    "state":{
                        "type":["string", "null"],
                        "antiSamyLevel":2,
                        "maxLength":80,
                        "description":"Non US state code for the organization",
                        "displayInPOST":True,
                        "displayInPUT":True,
                        "displayInGET":True
                    }
                }
            }

        }
    },
    "additionalProperties":False
}
